<?php

/** @CreatedBy : Mohit Jain
 *  @Description : User Model Functions
 */

namespace Dashboard\Model;

use Application\Controller\RestAPIClientController;
use Zend\Session\Container;
use Zend\Json\Json;

class User extends RestAPIClientController {

    public function apiUrl() {
        $config = new \Zend\Config\Config(include BASE_PATH . '/config/autoload/global.php');
        return $config->api->url;
    }


    public function getKycTypeList() {
        $kycTypeJsonDataArray = [];
        $val = '{"where": {"type": "kycP"}}';
        $val = rawurlencode($val);
        $url = $this->apiUrl() . "/document-type?&filter=" . $val;
        $resp = $this->get($url);
        $kycTypeJsonData = Json::decode($resp->getBody(), true);
        foreach ($kycTypeJsonData as $res) {
            $kycTypeJsonDataArray[$res['doc_type_id']] = $res['document_name'];
        }
        return $kycTypeJsonDataArray;
    }

    public function getPackageTypeList() {
        $packageTypeJsonDataArray = [];
        $url = $this->apiUrl() . "/package";
        $resp = $this->get($url);
        $packageTypeJsonData = Json::decode($resp->getBody(), true);
        if(count($packageTypeJsonData['data'])>0){
        foreach ($packageTypeJsonData['data'] as $res) {
            $packageTypeJsonDataArray[$res['id']] = $res['name'];
        }
        }
        return $packageTypeJsonDataArray;
    }

        public function getPaymentTypeList() {
        $paymentTypeJsonDataArray = [];
        $url = $this->apiUrl() . "/payment-type";
        $resp = $this->get($url);
        $paymentTypeJsonData = Json::decode($resp->getBody(), true);
        foreach ($paymentTypeJsonData as $res) {
            $paymentTypeJsonDataArray[$res['payment_type_id']] = $res['pay_type_mode'];
        }
        return $paymentTypeJsonDataArray;
    }

    public function getWeekDaysList() {
        $weekDaysJsonDataArray = [];
        $url = $this->apiUrl() . "/week-days-list";
        $resp = $this->get($url);
        $weekDaysJsonData = Json::decode($resp->getBody(), true);
        foreach ($weekDaysJsonData as $res) {
            $weekDaysJsonDataArray[$res['id']] = $res['name'];
        }
        return $weekDaysJsonDataArray;
    }

    public function getUserDutyTypeList($userId) {
        $dutyTypeJsonDataArray = [];
        $url = $this->apiUrl() . "/user/dutyTypeList?user_id=" . $userId;
        $resp = $this->get($url);
        $dutyTypeJsonData = Json::decode($resp->getBody(), true);
        foreach ($dutyTypeJsonData['responsedata'] as $res) {
            $dutyTypeJsonDataArray[$res['user_duty_id']] = $res['package_id'];
        }
        return $dutyTypeJsonDataArray;
    }

    public function getUserprefDriveCityList($userId) {
        $prefDriveJsonDataArray = [];
        $url = $this->apiUrl() . "/user/prefDriveCityList?user_id=" . $userId;
        $resp = $this->get($url);
        $prefDriveJsonData = Json::decode($resp->getBody(), true);
        foreach ($prefDriveJsonData['responsedata'] as $res) {
            $prefDriveJsonDataArray[$res['user_drive_city_id']] = $res['city_id'];
        }
        return $prefDriveJsonDataArray;
    }

    public function getUserpaymentTypeList($userId) {
        $paymentTypeJsonDataArray = [];
        $url = $this->apiUrl() . "/user/paymentList?user_id=" . $userId;
        $resp = $this->get($url);
        $paymentTypeJsonData = Json::decode($resp->getBody(), true);
        foreach ($paymentTypeJsonData['responsedata'] as $res) {
            $paymentTypeJsonDataArray[$res['user_payment_id']] = $res['payment_type_id'];
        }
        return $paymentTypeJsonDataArray;
    }

    public function getUserSpeakLanguageList($userId) {
        $speaklangJsonDataArray = [];
        $url = $this->apiUrl() . "/user/speakLangList?user_id=" . $userId;
        $resp = $this->get($url);
        $speaklangJsonData = Json::decode($resp->getBody(), true);
        foreach ($speaklangJsonData['responsedata'] as $res) {
            $speaklangJsonDataArray[$res['user_lang_id']] = $res['language_id'];
        }
        return $speaklangJsonDataArray;
    }

    public function getUserWriteLanguageList($userId) {
        $writelangJsonDataArray = [];
        $url = $this->apiUrl() . "/user/writeLangList?user_id=" . $userId;
        $resp = $this->get($url);
        $writelangJsonData = Json::decode($resp->getBody(), true);
        foreach ($writelangJsonData['responsedata'] as $res) {
            $writelangJsonDataArray[$res['user_lang_id']] = $res['language_id'];
        }
        return $writelangJsonDataArray;
    }

    public function getUserShiftLoginList($userId) {
        $shiftLoginJsonDataArray = [];
        $url = $this->apiUrl() . "/user/shiftLoginList?user_id=" . $userId;
        $resp = $this->get($url);
        $shiftLopinJsonData = Json::decode($resp->getBody(), true);
        foreach ($shiftLopinJsonData['responsedata'] as $res) {
            $shiftLoginJsonDataArray[$res['user_workingshift_id']] = $res['working_shift_id'];
        }
        return $shiftLoginJsonDataArray;
    }

    public function getUserWeekDaysList($userId) {
        $shiftLoginJsonDataArray = [];
        $url = $this->apiUrl() . "/user/weekOffList?user_id=" . $userId;
        $resp = $this->get($url);
        $shiftLopinJsonData = Json::decode($resp->getBody(), true);
        foreach ($shiftLopinJsonData['responsedata'] as $res) {
            $shiftLoginJsonDataArray[$res['user_weekoff_id']] = $res['week_id'];
        }
        return $shiftLoginJsonDataArray;
    }

    public function getLanguageList() {
        $languageJsonDataArray = [];
        $url = $this->apiUrl() . "/master-language";
        $resp = $this->get($url);
        $languageJsonData = Json::decode($resp->getBody(), true);
        foreach ($languageJsonData as $res) {
            $languageJsonDataArray[$res['language_id']] = $res['language_name'];
        }
        return $languageJsonDataArray;
    }

    public function getShiftLoginList() {
        $shiftJsonDataArray = [];
        $url = $this->apiUrl() . "/master-working-shift";
        $resp = $this->get($url);
        $shiftJsonData = Json::decode($resp->getBody(), true);
        foreach ($shiftJsonData as $res) {
            $shiftJsonDataArray[$res['working_shift_id']] = $res['shift'];
        }
        return $shiftJsonDataArray;
    }

    public function getPrefCityList() {
        $cityJsonDataArray = [];
        $url = $this->apiUrl() . "/city";
        $resp = $this->get($url);
        $cityJsonData = Json::decode($resp->getBody(), true);
        foreach ($cityJsonData as $res) {
            $cityJsonDataArray[$res['id']] = $res['name'];
        }
        return $cityJsonDataArray;
    }


    /**
     * Get Country List
     * @return JSON
     */
    public function getCountryList() {
        $countryJsonDataArray = [];
        $url = $this->apiUrl() . "/country";
        $resp = $this->get($url);
        $countryJsonData = Json::decode($resp->getBody(), true);
        foreach ($countryJsonData as $res) {
            $countryJsonDataArray[$res['id']] = $res['name'];
        }
        return $countryJsonDataArray;
    }

    /**
     * Get User Type List
     * @return JSON
     */
    public function getUserTypeList() {
        $roleJsonDataArray = [];
        $val = '{"where": {"IsApproved": "1"}}';
        $val = rawurlencode($val);
        $url = $this->apiUrl() . "/user-role?&filter=" . $val;

        //$url = $this->apiUrl() . "/user-role?filter=%7B%22where%22%3A%7B%22role_type%22%3A1%7D%7D";
        $resp = $this->get($url);
        $roleJsonData = Json::decode($resp->getBody(), true);
        foreach ($roleJsonData as $res) {
            $roleJsonDataArray[$res['Role_ID']] = $res['RoleName'];
        }
        return $roleJsonDataArray;
    }

    /**
     * Get User List
     * @return JSON
     */
    public function getUserList($data) {
        $url = $this->apiUrl() . "/user-management/users";
        $resp = $this->post($url, $data);
        $userList = Json::decode($resp->getBody(), true);
        if ($userList['responsedata'] != "") {
            $val = ["status" => true, "data" => Json::decode($resp->getBody(), true)];
        } else {
            $val = ["status" => false, "data" => Json::decode($resp->getBody(), true)];
        }
        return $val;
    }

    /**
     * Get DRIVER List
     * @return JSON
     */
    public function getDriverList($data) {
        $url = $this->apiUrl() . "/user-management/drivers";
        $resp = $this->post($url, $data);
        $userList = Json::decode($resp->getBody(), true);
        if ($userList['responsedata'] != "") {
            $val = ["status" => true, "data" => Json::decode($resp->getBody(), true)];
        } else {
            $val = ["status" => false, "data" => Json::decode($resp->getBody(), true)];
        }
        return $val;
    }

     /** API to GET SMS STATUS HISTORY */
    public function getSmsHistory($user_id) {
        $val = '{"where": {"uid": "' . $user_id . '"}}';
        $val = rawurlencode($val);
        $url = $this->apiUrl() . "/sms-status?&filter=" . $val;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

     /** API to GET EMAIL HISTORY */
    public function getEmailHistory($user_id) {
        $val = '{"where": {"uid": "' . $user_id . '"}}';
        $val = rawurlencode($val);
        $url = $this->apiUrl() . "/email-history?&filter=" . $val;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    /** API to GET ALLOCATION HISTORY */
    public function getStatusHistory($user_id, $from_date, $to_date) {
        $url = $this->apiUrl() . "/user/statusHistory?user_id=" . $user_id . "&from_date=" . $from_date . "&to_date=" . $to_date;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    /** API to GET ALLOCATION HISTORY */
    public function getAllocationHistory($user_id, $from_date, $to_date) {
        $url = $this->apiUrl() . "/user/allocationHistory?user_id=" . $user_id . "&from_date=" . $from_date . "&to_date=" . $to_date;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    /** API to GET BOOKING HISTORY */
    public function getBookingHistory($data) {
        $url = $this->apiUrl() . "/booking/bookingList";
        $resp = $this->post($url, $data);
        $data = Json::decode($resp->getBody(), true);
        $result = [];
        if($data['responsedata']['status']=='success'){
           $result  = $data['responsedata']['data'];
        }
        return $result;
    }

     /** API to GET DRIVER LEDGER */
    public function getDriverLedger($user_id, $from_date, $to_date) {
        $url = $this->apiUrl() . "/user/driverLedger?user_id=" . $user_id . "&from_date=" . $from_date . "&to_date=" . $to_date;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }


    /** API to GET DRIVER PAYMENT HISTORY */
    public function getPaymentHistory($user_id) {
        $url = $this->apiUrl() . "/user/paymentHistory?user_id=" . $user_id;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }


    /** Function to Update User STATUS */
    public function updateUserStatus($data) {
        $url = $this->apiUrl() . "/user-management/userStatus"; //die;
        $resp = $this->put($url, $data);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    /** Function to ADD NEW USER */
    public function addNewUser($data) {
        $url = $this->apiUrl() . "/user/adduser";
        $resp = $this->post($url, $data);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    /** Function to ADD NEW Role */
    public function addNewRole($data) {
        $url = $this->apiUrl() . "/user/adduser";
        $resp = $this->post($url, $data);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    /** API to GET STATE NAME FROM STATE ID */
    public function getStateId($id) {
        $url = $this->apiUrl() . "/state/".$id;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

      /** Function to ADD Staff USER */
    public function addstaff($data) {
        $url = $this->apiUrl() . "/user/signup";
        $resp = $this->post($url, $data);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

    public function updatestaff($data){
        $url = $this->apiUrl() . "/user/updatestaff";
        $resp = $this->post($url, $data);
        $data = Json::decode($resp->getBody(), true);
        return $data;
    }

   /** @Desc     : Function to Get User Staff By user Id & user type id
    * @CreatedBy : Mohit Verma
    * @createdDate : 4-May-2019
    **/
    public function getUserStaff($data) {
        $result = [];
        $userId     = $data['user_id'];
        $userTypeId = $data['user_type_id'];
        if($userId>0){
            $url = $this->apiUrl() . "/user/getuserstaff?user_id=$userId&user_type_id=$userTypeId";
            $resp = $this->get($url);
            $result = Json::decode($resp->getBody(), true);
        }
        return $result;
    }

    public function uploadImage(){
        $kycFile    =   $_FILES['kyc_upload']['name'];
        $kycFile    =   file_get_contents($_FILES['kyc_upload']['tmp_name']);
        $kycFile = base64_encode($kycFile);
        $finalData['base64image']= $kycFile;
        $url = $this->apiUrl() . "/user/uploadImg";
        $val = $this->post($url, $finalData);
        $JsonData = $val->getBody();
        $JsonData = Json::decode($JsonData, true);

    }


    public function getUserType($id){
        $url = $this->apiUrl() . "/user/getusertype?user_id=".$id;
        $resp = $this->get($url);
        $data = Json::decode($resp->getBody(), true);
        $val = $data['responsedata']['data']['user_type_id'];
        return $val;
    }


}
